# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Field.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Field.proto',
  package='iobinary',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Field',
  serialized_pb=b'\n\x0b\x46ield.proto\x12\x08iobinary\"\xc0\x01\n\x0bNestedField\x12\x11\n\tfieldName\x18\x01 \x02(\t\x12\x1d\n\x08seriesId\x18\x02 \x01(\x05:\x0b-2147483648\x12\x1d\n\x08intValue\x18\x03 \x01(\x05:\x0b-2147483648\x12\"\n\x0bstringValue\x18\x04 \x01(\t:\rENTRY_MISSING\x12\x13\n\x0b\x64oubleValue\x18\x05 \x03(\x01\x12\'\n\x08subField\x18\x06 \x03(\x0b\x32\x15.iobinary.NestedFieldB\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05\x46ield'
)




_NESTEDFIELD = _descriptor.Descriptor(
  name='NestedField',
  full_name='iobinary.NestedField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldName', full_name='iobinary.NestedField.fieldName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.NestedField.seriesId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='iobinary.NestedField.intValue', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='iobinary.NestedField.stringValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ENTRY_MISSING".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='iobinary.NestedField.doubleValue', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subField', full_name='iobinary.NestedField.subField', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=218,
)

_NESTEDFIELD.fields_by_name['subField'].message_type = _NESTEDFIELD
DESCRIPTOR.message_types_by_name['NestedField'] = _NESTEDFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NestedField = _reflection.GeneratedProtocolMessageType('NestedField', (_message.Message,), {
  'DESCRIPTOR' : _NESTEDFIELD,
  '__module__' : 'Field_pb2'
  # @@protoc_insertion_point(class_scope:iobinary.NestedField)
  })
_sym_db.RegisterMessage(NestedField)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InputFile.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameio.protobuf_definitions import Contract_pb2 as Contract__pb2
from fameio.protobuf_definitions import Field_pb2 as Field__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InputFile.proto',
  package='iobinary',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Input',
  serialized_pb=b'\n\x0fInputFile.proto\x12\x08iobinary\x1a\x0e\x43ontract.proto\x1a\x0b\x46ield.proto\"\xf3\x05\n\tInputData\x12\r\n\x05RunId\x18\x01 \x02(\x03\x12\x37\n\nSimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12/\n\x06Output\x18\x03 \x01(\x0b\x32\x1f.iobinary.InputData.OutputParam\x12\x35\n\nTimeSeries\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12+\n\x05\x41gent\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12.\n\x08\x43ontract\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x31\n\x07Program\x18\x07 \x01(\x0b\x32 .iobinary.InputData.ProgramParam\x1a*\n\x0cProgramParam\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Hash\x18\x02 \x01(\t\x1aJ\n\x0fSimulationParam\x12\x11\n\tStartTime\x18\x01 \x02(\x03\x12\x10\n\x08StopTime\x18\x02 \x02(\x03\x12\x12\n\nRandomSeed\x18\x03 \x02(\x03\x1aI\n\x0bOutputParam\x12\x10\n\x08Interval\x18\x01 \x02(\x05\x12\x0f\n\x07Process\x18\x02 \x02(\x05\x12\x17\n\x0f\x41\x63tiveClassName\x18\x03 \x03(\t\x1a\x91\x01\n\rTimeSeriesDao\x12\x10\n\x08seriesId\x18\x01 \x02(\x05\x12\x12\n\nseriesName\x18\x02 \x01(\t\x12\x32\n\x03row\x18\x03 \x03(\x0b\x32%.iobinary.InputData.TimeSeriesDao.Row\x1a&\n\x03Row\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\r\n\x05value\x18\x02 \x02(\x01\x1aO\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x11\n\tclassName\x18\x02 \x02(\t\x12$\n\x05\x66ield\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedFieldB\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05Input'
  ,
  dependencies=[Contract__pb2.DESCRIPTOR,Field__pb2.DESCRIPTOR,])




_INPUTDATA_PROGRAMPARAM = _descriptor.Descriptor(
  name='ProgramParam',
  full_name='iobinary.InputData.ProgramParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='iobinary.InputData.ProgramParam.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hash', full_name='iobinary.InputData.ProgramParam.Hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=434,
)

_INPUTDATA_SIMULATIONPARAM = _descriptor.Descriptor(
  name='SimulationParam',
  full_name='iobinary.InputData.SimulationParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='StartTime', full_name='iobinary.InputData.SimulationParam.StartTime', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='StopTime', full_name='iobinary.InputData.SimulationParam.StopTime', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='RandomSeed', full_name='iobinary.InputData.SimulationParam.RandomSeed', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=510,
)

_INPUTDATA_OUTPUTPARAM = _descriptor.Descriptor(
  name='OutputParam',
  full_name='iobinary.InputData.OutputParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Interval', full_name='iobinary.InputData.OutputParam.Interval', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Process', full_name='iobinary.InputData.OutputParam.Process', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ActiveClassName', full_name='iobinary.InputData.OutputParam.ActiveClassName', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=585,
)

_INPUTDATA_TIMESERIESDAO_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='iobinary.InputData.TimeSeriesDao.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='iobinary.InputData.TimeSeriesDao.Row.timeStep', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='iobinary.InputData.TimeSeriesDao.Row.value', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=733,
)

_INPUTDATA_TIMESERIESDAO = _descriptor.Descriptor(
  name='TimeSeriesDao',
  full_name='iobinary.InputData.TimeSeriesDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.InputData.TimeSeriesDao.seriesId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesName', full_name='iobinary.InputData.TimeSeriesDao.seriesName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='iobinary.InputData.TimeSeriesDao.row', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_TIMESERIESDAO_ROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=733,
)

_INPUTDATA_AGENTDAO = _descriptor.Descriptor(
  name='AgentDao',
  full_name='iobinary.InputData.AgentDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='iobinary.InputData.AgentDao.id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='iobinary.InputData.AgentDao.className', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='iobinary.InputData.AgentDao.field', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=814,
)

_INPUTDATA = _descriptor.Descriptor(
  name='InputData',
  full_name='iobinary.InputData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='RunId', full_name='iobinary.InputData.RunId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Simulation', full_name='iobinary.InputData.Simulation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Output', full_name='iobinary.InputData.Output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TimeSeries', full_name='iobinary.InputData.TimeSeries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Agent', full_name='iobinary.InputData.Agent', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Contract', full_name='iobinary.InputData.Contract', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Program', full_name='iobinary.InputData.Program', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_PROGRAMPARAM, _INPUTDATA_SIMULATIONPARAM, _INPUTDATA_OUTPUTPARAM, _INPUTDATA_TIMESERIESDAO, _INPUTDATA_AGENTDAO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=814,
)

_INPUTDATA_PROGRAMPARAM.containing_type = _INPUTDATA
_INPUTDATA_SIMULATIONPARAM.containing_type = _INPUTDATA
_INPUTDATA_OUTPUTPARAM.containing_type = _INPUTDATA
_INPUTDATA_TIMESERIESDAO_ROW.containing_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA_TIMESERIESDAO.fields_by_name['row'].message_type = _INPUTDATA_TIMESERIESDAO_ROW
_INPUTDATA_TIMESERIESDAO.containing_type = _INPUTDATA
_INPUTDATA_AGENTDAO.fields_by_name['field'].message_type = Field__pb2._NESTEDFIELD
_INPUTDATA_AGENTDAO.containing_type = _INPUTDATA
_INPUTDATA.fields_by_name['Simulation'].message_type = _INPUTDATA_SIMULATIONPARAM
_INPUTDATA.fields_by_name['Output'].message_type = _INPUTDATA_OUTPUTPARAM
_INPUTDATA.fields_by_name['TimeSeries'].message_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA.fields_by_name['Agent'].message_type = _INPUTDATA_AGENTDAO
_INPUTDATA.fields_by_name['Contract'].message_type = Contract__pb2._PROTOCONTRACT
_INPUTDATA.fields_by_name['Program'].message_type = _INPUTDATA_PROGRAMPARAM
DESCRIPTOR.message_types_by_name['InputData'] = _INPUTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputData = _reflection.GeneratedProtocolMessageType('InputData', (_message.Message,), {

  'ProgramParam' : _reflection.GeneratedProtocolMessageType('ProgramParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_PROGRAMPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.ProgramParam)
    })
  ,

  'SimulationParam' : _reflection.GeneratedProtocolMessageType('SimulationParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_SIMULATIONPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.SimulationParam)
    })
  ,

  'OutputParam' : _reflection.GeneratedProtocolMessageType('OutputParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_OUTPUTPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.OutputParam)
    })
  ,

  'TimeSeriesDao' : _reflection.GeneratedProtocolMessageType('TimeSeriesDao', (_message.Message,), {

    'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO_ROW,
      '__module__' : 'InputFile_pb2'
      # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao.Row)
      })
    ,
    'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao)
    })
  ,

  'AgentDao' : _reflection.GeneratedProtocolMessageType('AgentDao', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_AGENTDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.AgentDao)
    })
  ,
  'DESCRIPTOR' : _INPUTDATA,
  '__module__' : 'InputFile_pb2'
  # @@protoc_insertion_point(class_scope:iobinary.InputData)
  })
_sym_db.RegisterMessage(InputData)
_sym_db.RegisterMessage(InputData.ProgramParam)
_sym_db.RegisterMessage(InputData.SimulationParam)
_sym_db.RegisterMessage(InputData.OutputParam)
_sym_db.RegisterMessage(InputData.TimeSeriesDao)
_sym_db.RegisterMessage(InputData.TimeSeriesDao.Row)
_sym_db.RegisterMessage(InputData.AgentDao)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# !/usr/bin/env python
# -*- coding:utf-8 -*-

import pandas as pd

from .FameTime import FameTime, START_IN_REAL_TIME


class TimeSeriesManager:
    """Manages matching of files to time series ids and their protobuf representation"""
    ids_of_time_series = {}
    id_count = -1
    already_registered = "file already registered"

    def get_time_series_id(self, file_name):
        """Returns the id assigned to the given file name"""
        return self.ids_of_time_series.get(file_name)

    def time_series_is_registered(self, file_name):
        """Returns True if the file is already registered"""
        return file_name in self.ids_of_time_series.keys()

    def register_time_series(self, file_name):
        """Assigns an id to the given file or raises an Exception if the file is already registered"""
        if not self.time_series_is_registered(file_name):
            self.id_count += 1
            self.ids_of_time_series[file_name] = self.id_count
        else:
            raise Exception(TimeSeriesManager.already_registered)

    def save_get_time_series_id(self, file_name):
        """Returns the id of the time series - if the file is not yet registered, assigns an id"""
        if not self.time_series_is_registered(file_name):
            self.register_time_series(file_name)
        return self.get_time_series_id(file_name)

    def add_time_series_to_proto_buffer(self, proto_buffer):
        """Adds all registered files to given protobuf time series"""
        for identifier, unique_id in self.ids_of_time_series.items():
            series = proto_buffer.TimeSeries.add()
            series.seriesId = unique_id
            if isinstance(identifier, str):
                series.seriesName = identifier
                data_frame = pd.read_csv(identifier, sep=';', header=None)
                TimeSeriesManager.add_rows_to_series(series, data_frame)
            else:
                series.seriesName = "Constant value: {}".format(identifier)
                data_frame = pd.DataFrame({'time': [START_IN_REAL_TIME],
                                           'value': [identifier],
                                           })
                TimeSeriesManager.add_rows_to_series(series, data_frame)

    @staticmethod
    def add_rows_to_series(series, data_frame):
        for (datetime_string, value) in data_frame.itertuples(index=False):
            row = series.row.add()
            row.timeStep = int(FameTime.convert_time_string_to_fame_time_step(datetime_string))
            row.value = value



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Services.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Services.proto',
  package='communication',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\010Services',
  serialized_pb=b'\n\x0eServices.proto\x12\rcommunication\"!\n\rScheduledTime\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\"v\n\nProtoSetup\x12\x12\n\noutputPath\x18\x01 \x02(\t\x12\x19\n\x11\x61gentPackageNames\x18\x02 \x03(\t\x12\x1b\n\x13messagePackageNames\x18\x03 \x03(\t\x12\x1c\n\x14portablePackageNames\x18\x04 \x03(\t\"\x1f\n\rWarmUpMessage\x12\x0e\n\x06needed\x18\x01 \x02(\x08\"\xcc\x03\n\x06Output\x12\x32\n\tagentType\x18\x01 \x03(\x0b\x32\x1f.communication.Output.AgentType\x12,\n\x06series\x18\x02 \x03(\x0b\x32\x1c.communication.Output.Series\x1a\x81\x01\n\tAgentType\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x34\n\x05\x66ield\x18\x02 \x03(\x0b\x32%.communication.Output.AgentType.Field\x1a+\n\x05\x46ield\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\x11\n\tfieldName\x18\x02 \x02(\t\x1a\xdb\x01\n\x06Series\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x0f\n\x07\x61gentId\x18\x02 \x02(\x03\x12/\n\x04line\x18\x03 \x03(\x0b\x32!.communication.Output.Series.Line\x1a|\n\x04Line\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\x38\n\x06\x63olumn\x18\x02 \x03(\x0b\x32(.communication.Output.Series.Line.Column\x1a(\n\x06\x43olumn\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x02(\x01\"1\n\x0b\x41\x64\x64ressBook\x12\x11\n\tprocessId\x18\x01 \x02(\x05\x12\x0f\n\x07\x61gentId\x18\x02 \x03(\x03\x42 \n\x14\x64\x65.dlr.fame.protobufB\x08Services'
)




_SCHEDULEDTIME = _descriptor.Descriptor(
  name='ScheduledTime',
  full_name='communication.ScheduledTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='communication.ScheduledTime.timeStep', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=66,
)


_PROTOSETUP = _descriptor.Descriptor(
  name='ProtoSetup',
  full_name='communication.ProtoSetup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputPath', full_name='communication.ProtoSetup.outputPath', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agentPackageNames', full_name='communication.ProtoSetup.agentPackageNames', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messagePackageNames', full_name='communication.ProtoSetup.messagePackageNames', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portablePackageNames', full_name='communication.ProtoSetup.portablePackageNames', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=186,
)


_WARMUPMESSAGE = _descriptor.Descriptor(
  name='WarmUpMessage',
  full_name='communication.WarmUpMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='needed', full_name='communication.WarmUpMessage.needed', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=219,
)


_OUTPUT_AGENTTYPE_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='communication.Output.AgentType.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldId', full_name='communication.Output.AgentType.Field.fieldId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldName', full_name='communication.Output.AgentType.Field.fieldName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=460,
)

_OUTPUT_AGENTTYPE = _descriptor.Descriptor(
  name='AgentType',
  full_name='communication.Output.AgentType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='className', full_name='communication.Output.AgentType.className', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='communication.Output.AgentType.field', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OUTPUT_AGENTTYPE_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=460,
)

_OUTPUT_SERIES_LINE_COLUMN = _descriptor.Descriptor(
  name='Column',
  full_name='communication.Output.Series.Line.Column',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldId', full_name='communication.Output.Series.Line.Column.fieldId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='communication.Output.Series.Line.Column.value', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=682,
)

_OUTPUT_SERIES_LINE = _descriptor.Descriptor(
  name='Line',
  full_name='communication.Output.Series.Line',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='communication.Output.Series.Line.timeStep', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='communication.Output.Series.Line.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OUTPUT_SERIES_LINE_COLUMN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=682,
)

_OUTPUT_SERIES = _descriptor.Descriptor(
  name='Series',
  full_name='communication.Output.Series',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='className', full_name='communication.Output.Series.className', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agentId', full_name='communication.Output.Series.agentId', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='communication.Output.Series.line', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OUTPUT_SERIES_LINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=682,
)

_OUTPUT = _descriptor.Descriptor(
  name='Output',
  full_name='communication.Output',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agentType', full_name='communication.Output.agentType', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series', full_name='communication.Output.series', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OUTPUT_AGENTTYPE, _OUTPUT_SERIES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=682,
)


_ADDRESSBOOK = _descriptor.Descriptor(
  name='AddressBook',
  full_name='communication.AddressBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processId', full_name='communication.AddressBook.processId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agentId', full_name='communication.AddressBook.agentId', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=733,
)

_OUTPUT_AGENTTYPE_FIELD.containing_type = _OUTPUT_AGENTTYPE
_OUTPUT_AGENTTYPE.fields_by_name['field'].message_type = _OUTPUT_AGENTTYPE_FIELD
_OUTPUT_AGENTTYPE.containing_type = _OUTPUT
_OUTPUT_SERIES_LINE_COLUMN.containing_type = _OUTPUT_SERIES_LINE
_OUTPUT_SERIES_LINE.fields_by_name['column'].message_type = _OUTPUT_SERIES_LINE_COLUMN
_OUTPUT_SERIES_LINE.containing_type = _OUTPUT_SERIES
_OUTPUT_SERIES.fields_by_name['line'].message_type = _OUTPUT_SERIES_LINE
_OUTPUT_SERIES.containing_type = _OUTPUT
_OUTPUT.fields_by_name['agentType'].message_type = _OUTPUT_AGENTTYPE
_OUTPUT.fields_by_name['series'].message_type = _OUTPUT_SERIES
DESCRIPTOR.message_types_by_name['ScheduledTime'] = _SCHEDULEDTIME
DESCRIPTOR.message_types_by_name['ProtoSetup'] = _PROTOSETUP
DESCRIPTOR.message_types_by_name['WarmUpMessage'] = _WARMUPMESSAGE
DESCRIPTOR.message_types_by_name['Output'] = _OUTPUT
DESCRIPTOR.message_types_by_name['AddressBook'] = _ADDRESSBOOK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScheduledTime = _reflection.GeneratedProtocolMessageType('ScheduledTime', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTIME,
  '__module__' : 'Services_pb2'
  # @@protoc_insertion_point(class_scope:communication.ScheduledTime)
  })
_sym_db.RegisterMessage(ScheduledTime)

ProtoSetup = _reflection.GeneratedProtocolMessageType('ProtoSetup', (_message.Message,), {
  'DESCRIPTOR' : _PROTOSETUP,
  '__module__' : 'Services_pb2'
  # @@protoc_insertion_point(class_scope:communication.ProtoSetup)
  })
_sym_db.RegisterMessage(ProtoSetup)

WarmUpMessage = _reflection.GeneratedProtocolMessageType('WarmUpMessage', (_message.Message,), {
  'DESCRIPTOR' : _WARMUPMESSAGE,
  '__module__' : 'Services_pb2'
  # @@protoc_insertion_point(class_scope:communication.WarmUpMessage)
  })
_sym_db.RegisterMessage(WarmUpMessage)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {

  'AgentType' : _reflection.GeneratedProtocolMessageType('AgentType', (_message.Message,), {

    'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
      'DESCRIPTOR' : _OUTPUT_AGENTTYPE_FIELD,
      '__module__' : 'Services_pb2'
      # @@protoc_insertion_point(class_scope:communication.Output.AgentType.Field)
      })
    ,
    'DESCRIPTOR' : _OUTPUT_AGENTTYPE,
    '__module__' : 'Services_pb2'
    # @@protoc_insertion_point(class_scope:communication.Output.AgentType)
    })
  ,

  'Series' : _reflection.GeneratedProtocolMessageType('Series', (_message.Message,), {

    'Line' : _reflection.GeneratedProtocolMessageType('Line', (_message.Message,), {

      'Column' : _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), {
        'DESCRIPTOR' : _OUTPUT_SERIES_LINE_COLUMN,
        '__module__' : 'Services_pb2'
        # @@protoc_insertion_point(class_scope:communication.Output.Series.Line.Column)
        })
      ,
      'DESCRIPTOR' : _OUTPUT_SERIES_LINE,
      '__module__' : 'Services_pb2'
      # @@protoc_insertion_point(class_scope:communication.Output.Series.Line)
      })
    ,
    'DESCRIPTOR' : _OUTPUT_SERIES,
    '__module__' : 'Services_pb2'
    # @@protoc_insertion_point(class_scope:communication.Output.Series)
    })
  ,
  'DESCRIPTOR' : _OUTPUT,
  '__module__' : 'Services_pb2'
  # @@protoc_insertion_point(class_scope:communication.Output)
  })
_sym_db.RegisterMessage(Output)
_sym_db.RegisterMessage(Output.AgentType)
_sym_db.RegisterMessage(Output.AgentType.Field)
_sym_db.RegisterMessage(Output.Series)
_sym_db.RegisterMessage(Output.Series.Line)
_sym_db.RegisterMessage(Output.Series.Line.Column)

AddressBook = _reflection.GeneratedProtocolMessageType('AddressBook', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSBOOK,
  '__module__' : 'Services_pb2'
  # @@protoc_insertion_point(class_scope:communication.AddressBook)
  })
_sym_db.RegisterMessage(AddressBook)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# !/usr/bin/env python
# -*- coding:utf-8 -*-


from fameio.scripts.make_config import run as make_config
from fameio.scripts.make_config import DEFAULT_CONFIG as defaults_make_config
from fameio.scripts.convert_results import run as convert_results
from fameio.scripts.convert_results import DEFAULT_CONFIG as defaults_convert_results
from fameio.source.tools import arg_handling_make_config, arg_handling_convert_results


def makeFameRunConfig():
	input_file, run_config = arg_handling_make_config(defaults_make_config)
	make_config(input_file, run_config)


def convertFameResults():
	input_file, run_config = arg_handling_convert_results(defaults_convert_results)
	convert_results(input_file, run_config)



# !/usr/bin/env python
# -*- coding:utf-8 -*-

from setuptools import setup, find_packages


__author__ = ["Felix Nitsch", "Christoph Schimeczek", "Ulrich Frey", "Marc Deissenroth-Uhrig", "Benjamin Fuchs"]
__copyright__ = "Copyright 2021, German Aerospace Center (DLR)"
__credits__ = ["Kristina Nienhaus", "Evelyn Sperber", "Seyedfarzad Sarfarazi"]

__license__ = "Apache License 2.0"
__maintainer__ = "Felix Nitsch"
__email__ = "fame@dlr.de"
__status__ = "Production"


def readme():
      with open('README.md') as f:
            return f.read()


setup(name='fameio',
      version='1.2.0',
      description='Python scripts for operation of FAME models',
      long_description='''
                       Python scripts for FAME models, generation of protobuf input files and conversion of protobuf 
                       output files. The package is also formerly known as `famepy`.
                       ''',
      keywords=['FAME', 'agent-based modelling'],
      url='https://gitlab.com/fame-framework/fame-io/',
      author=', '.join(__author__),
      author_email=__email__,
      license=__license__,
      package_dir={'': 'src'},
      packages=find_packages(where='src'),
      entry_points={
            'console_scripts': [
                  'makeFameRunConfig=fameio.scripts:makeFameRunConfig',
                  'convertFameResults=fameio.scripts:convertFameResults',
            ],
      },
      classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: Apache Software License",
            "Operating System :: OS Independent",
      ],
      install_requires=['pandas', 'protobuf', 'pyyaml'],
      extras_require={'test': ['pytest']},
      include_package_data=True,
      zip_safe=False,
      python_requires='>=3.6',
      )



# !/usr/bin/env python
# -*- coding:utf-8 -*-

from enum import Enum
import logging as log

from .tools import log_and_raise


class FieldValidator:
    """ Handles validation of agent `Attributes` in scenario YAML files based on given `schema`"""
    type_schema = dict()

    def __init__(self, schema):
        """Load rules for given Schema"""
        for agent, agent_details in schema['AgentTypes'].items():
            if agent_details is None:
                log.info("Schema for '{}' is empty. Please make sure to provide valid `Inputs` and/or `Products` in "
                         "order to ensure a correct validation.".format(agent))
            else:
                if 'Attributes' in agent_details:
                    self.type_schema[agent] = agent_details['Attributes']
                else:
                    log.info("Agent '{}' has no specified 'Attributes'.".format(agent))

    def get_field_type(self, agent_type, field_name):
        """ Returns FieldType of given `field_name` of `agent_type` as specified in scenario schema """
        try:
            agent = self.type_schema[agent_type]
        except KeyError:
            log_and_raise("Schema has no agent '{}'.".format(agent_type))

        try:
            field = agent[field_name]
        except KeyError:
            log_and_raise("Schema agent '{}' has no field '{}'.".format(agent_type, field_name))

        try:
            field_type = field['FieldType']
        except KeyError:
            log_and_raise("'FieldType' missing in agent '{}' field '{}'.".format(agent_type, field_name))

        try:
            return FieldType[field_type.upper()]
        except KeyError:
            log_and_raise("FieldType '{}' not implemented.".format(field_type.upper()))

    def is_valid(self, agent_type, field_name, field_value):
        """ Returns true if `field_value` can be matched to given `data_type` """
        data_type = self.get_field_type(agent_type, field_name)
        return FieldValidator.is_compatible(data_type, field_value) and \
               FieldValidator.allowed_value(self.type_schema[agent_type][field_name], field_value)

    @staticmethod
    def is_compatible(data_type, field_value):
        """ Returns true if field type of given `field_value` is compatible to required `field_type`. """
        if data_type is FieldType.INTEGER:
            return isinstance(field_value, int)
        elif data_type is FieldType.DOUBLE:
            return isinstance(field_value, (int, float))
        elif data_type is FieldType.DOUBLE_LIST:
            return all(isinstance(x, (int, float)) for x in field_value)
        elif data_type is FieldType.ENUM:
            return isinstance(field_value, str)
        elif data_type is FieldType.TIME_SERIES:
            return isinstance(field_value, (str, int, float))
        else:
            log_and_raise("Validation not implemented for FieldType '{}'.".format(data_type))

    @staticmethod
    def allowed_value(field_definition, field_value):
        """
        Returns true if `field_value` matches one allowed 'Values' of `field_definition` or true,
        if no 'Values'-restrictions are specified.
        """
        if 'Values' in field_definition:
            return field_value in field_definition['Values']
        return True


class FieldType(Enum):
    INTEGER = 0
    DOUBLE = 1
    ENUM = 2
    TIME_SERIES = 3
    DOUBLE_LIST = 4



# !/usr/bin/env python
# -*- coding:utf-8 -*-

from enum import Enum

import datetime as dt
import math


START_IN_REAL_TIME = '2000-01-01_00:00:00'
DATE_FORMAT = '%Y-%m-%d_%H:%M:%S'
FAME_FIRST_DATETIME = dt.datetime.strptime(START_IN_REAL_TIME, DATE_FORMAT)


class TimeUnit(Enum):
    SECONDS = 0
    MINUTES = 1
    HOURS = 2
    DAYS = 3
    WEEKS = 4
    MONTHS = 5
    YEARS = 6


class Constants:
    STEPS_PER_SECOND = 1
    SECONDS_PER_MINUTE = 60
    MINUTES_PER_HOUR = 60
    HOURS_PER_DAY = 24
    DAYS_PER_YEAR = 365
    STEPS_PER_MINUTE = STEPS_PER_SECOND * SECONDS_PER_MINUTE
    STEPS_PER_HOUR = STEPS_PER_MINUTE * MINUTES_PER_HOUR
    STEPS_PER_DAY = STEPS_PER_HOUR * HOURS_PER_DAY
    STEPS_PER_YEAR = STEPS_PER_DAY * DAYS_PER_YEAR
    STEPS_PER_WEEK = STEPS_PER_DAY * 7
    STEPS_PER_MONTH = STEPS_PER_YEAR / 12

    steps_per_unit = {TimeUnit.SECONDS: STEPS_PER_SECOND,
                      TimeUnit.MINUTES: STEPS_PER_MINUTE,
                      TimeUnit.HOURS: STEPS_PER_HOUR,
                      TimeUnit.DAYS: STEPS_PER_DAY,
                      TimeUnit.WEEKS: STEPS_PER_WEEK,
                      TimeUnit.MONTHS: STEPS_PER_MONTH,
                      TimeUnit.YEARS: STEPS_PER_YEAR,
                      }


class FameTime:
    """Handles conversion of TimeSteps and TimeDurations into TimeStamps and vice versa"""

    @staticmethod
    def convert_time_string_to_fame_time_step(datetime_string):
        """Converts real Datetime string to FAME time step"""
        datetime = dt.datetime.strptime(datetime_string, DATE_FORMAT)
        years_since_start_time = datetime.year - FAME_FIRST_DATETIME.year
        beginning_of_year = dt.datetime(year=datetime.year, month=1, day=1, hour=0, minute=0, second=0)
        seconds_since_beginning_of_year = (datetime - beginning_of_year).total_seconds()
        return years_since_start_time * Constants.STEPS_PER_YEAR + seconds_since_beginning_of_year * Constants.STEPS_PER_SECOND

    @staticmethod
    def convert_fame_time_step_to_datetime_string(fame_time_steps):
        """Converts fame time step to Datetime string"""
        years_since_start_time = math.floor(fame_time_steps / Constants.STEPS_PER_YEAR)
        current_year = years_since_start_time + 2000
        beginning_of_year = dt.datetime(year=current_year, month=1, day=1, hour=0, minute=0, second=0)
        seconds_in_current_year = (fame_time_steps - years_since_start_time * Constants.STEPS_PER_YEAR) / Constants.STEPS_PER_SECOND
        datetime = beginning_of_year + dt.timedelta(seconds=seconds_in_current_year)
        return datetime.strftime(DATE_FORMAT)

    @staticmethod
    def convert_time_span_to_fame_time_steps(value, unit):
        """Converts value of TimeUnit.UNIT to fame time steps"""
        steps = Constants.steps_per_unit.get(unit)
        if steps:
            return steps * value
        else:
            raise Exception("TimeUnit conversion of '{}' not implemented.".format(unit))
